@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vector-binary-instances
-version: 0.2.3.1
-id: vector-binary-instances-0.2.3.1-2255e15260ecf66ec12e6381e175b94d
-key: vecto_AfoM4V7e5UwKO3jo4zR1YO
+version: 0.2.3.2
+id: vector-binary-instances-0.2.3.2-10501af4370a6bd9af714ba6aadb9040
+key: vecto_66A51JbQFmQ18eRvXqdGMR
 license: BSD3
 maintainer: dons00@gmail.com, bos@serpentine.com, Ben Gamari <ben@smart-cactus.org>
 stability: Experimental
@@ -34,10 +34,10 @@ exposed: True
 exposed-modules:
     Data.Vector.Binary
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-binary-instances-0.2.3.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-binary-instances-0.2.3.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-binary-instances-0.2.3.1
-hs-libraries: HSvector-binary-instances-0.2.3.1-AfoM4V7e5UwKO3jo4zR1YO
+import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-binary-instances-0.2.3.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-binary-instances-0.2.3.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-binary-instances-0.2.3.2
+hs-libraries: HSvector-binary-instances-0.2.3.2-66A51JbQFmQ18eRvXqdGMR
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
